@@ -3,7 +3,7 @@
 #' 
 #' @param A An adjacency matrix of network data (or an array of matrices)
 #' 
-#' @return Returns an adjancency matrix of 1's and 0's
+#' @return Returns an adjacency matrix of 1's and 0's
 #' 
 #' @examples
 #' A <- TMFG(neoOpen)$A
@@ -17,7 +17,7 @@
 binarize <- function (A)
 {
     bin <- ifelse(A!=0,1,0)
-    row.names(bin) <- colnames(A)
+    row.names(bin) <- row.names(A)
     colnames(bin) <- colnames(A)
     
     return(bin)
